==> nextcloud-app-bookmarks-1%3A3.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/es_MX.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
    "A Bookmark manager for Nextcloud" : "Un administrador de Marcadores para Nextcloud",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Delete" : "Borrar",
    "Save" : "Guardar",
    "New folder" : "Carpeta nueva ",
    "Grid view" : "Vista de cuadrícula",
    "List view" : "Vista de lista",
    "Create" : "Crear",
    "Cancel" : "Cancelar",
    "Public" : "Público",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Recently added" : "Agregado recientemente",
    "Alphabetically" : "Alfabéticamente",
    "Last modified" : "Última modificación",
    "Clear data" : "Borrar datos",
    "Bookmarklet" : "Marcador a código ",
    "URL" : "URL",
    "Tags" : "Etiquetas",
    "Notes" : "Notas",
    "Sharing" : "Compartiendo",
    "Owner" : "Dueño",
    "Share link" : "Compartir liga",
    "Copy link" : "Copiar liga",
    "Allow editing" : "Permitir edición",
    "Link copied" : "Vinculo copiado",
    "Select" : "Seleccionar",
    "Privacy" : "Privacidad",
    "Add a bookmark" : "Agregar un marcador",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Title" : "Título",
    "Link" : "Liga",
    "Folder" : "Carpeta"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A3.4.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/es_MX.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Marcadores",
    "No file provided for import" : "No se especificó un archivo para importar",
    "Unsupported file type for import" : "Tipo de archivo no soportado para importar",
    "A Bookmark manager for Nextcloud" : "Un administrador de Marcadores para Nextcloud",
    "Details" : "Detalles",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Delete" : "Borrar",
    "New" : "Nuevo",
    "New folder" : "Carpeta nueva ",
    "Grid view" : "Vista de cuadrícula",
    "List view" : "Vista de lista",
    "Select all" : "Seleccionar todo",
    "Cancel" : "Cancelar",
    "All bookmarks" : "Todos los marcadores",
    "Recent" : "Reciente",
    "Add a bookmark" : "Agregar un marcador",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Recently added" : "Agregado recientemente",
    "Alphabetically" : "Alfabéticamente",
    "Last modified" : "Última modificación",
    "Bookmarklet" : "Marcador a código ",
    "Clear data" : "Borrar datos",
    "Title" : "Título",
    "Link" : "Liga",
    "Tags" : "Etiquetas",
    "Attachments" : "Adjuntos",
    "Notes" : "Notas",
    "Owner" : "Dueño",
    "Sharing" : "Compartiendo",
    "Share link" : "Compartir liga",
    "Copy link" : "Copiar liga",
    "Allow editing" : "Permitir edición",
    "Link copied" : "Vinculo copiado",
    "Select" : "Seleccionar",
    "Privacy" : "Privacidad",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
    "Folder" : "Carpeta",
    "Save" : "Guardar"
},
"nplurals=2; plural=(n != 1);");
